@@ -1,26 +1,11 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
 
-Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
-                          wuebben@kde.org
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KCALC_H_
-#define KCALC_H_
+#pragma once
 
 class Constants;
 class QButtonGroup;
@@ -47,33 +32,37 @@ class KCalcStatusBar;
   operation button is pressed, e.g. "core.Plus(display_number)".
  */
 
-#include "kcalc_core.h"
 #include "kcalc_button.h"
 #include "kcalc_const_button.h"
+#include "kcalc_core.h"
 
-#include "ui_kcalc.h"
-#include "ui_general.h"
-#include "ui_fonts.h"
-#include "ui_constants.h"
 #include "ui_colors.h"
+#include "ui_constants.h"
+#include "ui_fonts.h"
+#include "ui_general.h"
+#include "ui_kcalc.h"
 
 #include <array>
 #include <kxmlguiwindow.h>
 
-class General: public QWidget, public Ui::General
+class General : public QWidget, public Ui::General
 {
     Q_OBJECT
 public:
-    explicit General(QWidget *parent) : QWidget(parent) {
+    explicit General(QWidget *parent)
+        : QWidget(parent)
+    {
         setupUi(this);
     }
 };
 
-class Fonts: public QWidget, public Ui::Fonts
+class Fonts : public QWidget, public Ui::Fonts
 {
     Q_OBJECT
 public:
-    explicit Fonts(QWidget *parent) : QWidget(parent) {
+    explicit Fonts(QWidget *parent)
+        : QWidget(parent)
+    {
         setupUi(this);
     }
 };
@@ -82,7 +71,9 @@ class Constants : public QWidget, public Ui::Constants
 {
     Q_OBJECT
 public:
-    explicit Constants(QWidget *parent) : QWidget(parent) {
+    explicit Constants(QWidget *parent)
+        : QWidget(parent)
+    {
         setupUi(this);
     }
 };
@@ -91,30 +82,28 @@ class Colors : public QWidget, public Ui::Colors
 {
     Q_OBJECT
 public:
-    explicit Colors(QWidget *parent) : QWidget(parent) {
+    explicit Colors(QWidget *parent)
+        : QWidget(parent)
+    {
         setupUi(this);
     }
 };
 
-
 class KCalculator : public KXmlGuiWindow, private Ui::KCalculator
 {
     Q_OBJECT
 
 public:
     explicit KCalculator(QWidget *parent = nullptr);
-    ~KCalculator();
+    ~KCalculator() override;
 
 Q_SIGNALS:
     void switchMode(ButtonModeFlags, bool);
     void switchShowAccels(bool);
 
 public:
-    enum UpdateFlag {
-        UPDATE_FROM_CORE    = 1,
-        UPDATE_STORE_RESULT = 2
-    };
-    
+    enum UpdateFlag { UPDATE_FROM_CORE = 1, UPDATE_STORE_RESULT = 2 };
+
     Q_DECLARE_FLAGS(UpdateFlags, UpdateFlag)
 
 private:
@@ -123,14 +112,14 @@ private:
     void updateGeometry();
     void setupMainActions();
     void setupKeys();
-	void setupNumberKeys();
-	void setupRightKeypad();
-	void setupNumericKeypad();
-	void setupLogicKeys();
-	void setupScientificKeys();
-	void setupStatisticKeys();
-	void setupConstantsKeys();
-	void setupMiscKeys();
+    void setupNumberKeys();
+    void setupRightKeypad();
+    void setupNumericKeypad();
+    void setupLogicKeys();
+    void setupScientificKeys();
+    void setupStatisticKeys();
+    void setupConstantsKeys();
+    void setupMiscKeys();
     void keyPressEvent(QKeyEvent *e) override;
     void keyReleaseEvent(QKeyEvent *e) override;
     void setPrecision();
@@ -138,22 +127,23 @@ private:
     void setBase();
 
     void updateDisplay(UpdateFlags flags);
+    void updateHistoryWithFunction(CalcEngine::Operation);
     KCalcStatusBar *statusBar();
-	
+
     // button sets
     void showMemButtons(bool toggled);
     void showStatButtons(bool toggled);
     void showScienceButtons(bool toggled);
     void showLogicButtons(bool toggled);
-	
-	KCalcConstMenu *createConstantsMenu();
+
+    KCalcConstMenu *createConstantsMenu();
 
 protected Q_SLOTS:
     void changeButtonNames();
     void updateSettings();
     void setColors();
     void setFonts();
-    void EnterEqual();
+    void EnterEqual(CalcEngine::Repeat allow_repeat = CalcEngine::REPEAT_ALLOW);
     void showSettings();
 
     // Mode
@@ -162,6 +152,7 @@ protected Q_SLOTS:
     void slotSetStatisticMode();
     void slotSetNumeralMode();
 
+    void slotHistoryshow(bool toggled);
     void slotConstantsShow(bool toggled);
     void slotBitsetshow(bool toggled);
     void slotAngleSelected(QAbstractButton *button);
@@ -210,7 +201,7 @@ protected Q_SLOTS:
     void slotStatClearDataclicked();
     void slotHyptoggled(bool flag);
     void slotConstclicked(int);
-	void slotBackspaceclicked();
+    void slotBackspaceclicked();
 
     void slotConstantToDisplay(const science_constant &const_chosen);
     void slotChooseScientificConst0(const science_constant &);
@@ -228,65 +219,52 @@ protected Q_SLOTS:
     void slotPaste();
 
 private:
-    enum StatusField {
-        ShiftField = 0,
-        BaseField,
-        AngleField,
-        MemField
-    };
-	
-    enum AngleMode {
-        DegMode = 0,
-        RadMode,
-        GradMode
-    };
-    
-	enum BaseMode {
-        BinMode = 2,
-        OctMode = 8,
-        DecMode = 10,
-        HexMode = 16
-    };
+    enum StatusField { ShiftField = 0, BaseField, AngleField, MemField };
+
+    enum AngleMode { DegMode = 0, RadMode, GradMode };
+
+    enum BaseMode { BinMode = 2, OctMode = 8, DecMode = 10, HexMode = 16 };
 
 private:
-    bool shift_mode_;
-    bool hyp_mode_;
+    bool shift_mode_ = false;
+    bool hyp_mode_ = false;
+    bool update_history_window_ = false;
     KNumber memory_num_;
 
     int angle_mode_; // angle modes for trigonometric values
 
-	KCalcConstMenu* constants_menu_;
+    KCalcConstMenu *constants_menu_ = nullptr;
 
-    Constants*          constants_; // this is the dialog for configuring const buttons
+    Constants *constants_ = nullptr; // this is the dialog for configuring const buttons
 
-    QButtonGroup* angle_choose_group_;
-    QButtonGroup*  base_choose_group_;
+    QButtonGroup *angle_choose_group_ = nullptr;
+    QButtonGroup *base_choose_group_ = nullptr;
     // num_button_group_: 0-9 = digits, 0xA-0xF = hex-keys
-    QButtonGroup*  num_button_group_;
+    QButtonGroup *num_button_group_ = nullptr;
 
-    QList<QAbstractButton*> logic_buttons_;
-    QList<QAbstractButton*> scientific_buttons_;
-    QList<QAbstractButton*> stat_buttons_;
-    QList<QAbstractButton*> const_buttons_;
+    QList<QAbstractButton *> logic_buttons_;
+    QList<QAbstractButton *> scientific_buttons_;
+    QList<QAbstractButton *> stat_buttons_;
+    QList<QAbstractButton *> const_buttons_;
 
-    std::array<QLabel*, 4> base_conversion_labels_;
+    std::array<QLabel *, 4> base_conversion_labels_;
 
-    KToggleAction *action_bitset_show_;
-    KToggleAction *action_constants_show_;
+    KToggleAction *action_history_show_ = nullptr;
+    KToggleAction *action_bitset_show_ = nullptr;
+    KToggleAction *action_constants_show_ = nullptr;
 
-    KToggleAction *action_mode_simple_;
-    KToggleAction *action_mode_science_;
-    KToggleAction *action_mode_statistic_;
-    KToggleAction *action_mode_numeral_;
+    KToggleAction *action_mode_simple_ = nullptr;
+    KToggleAction *action_mode_science_ = nullptr;
+    KToggleAction *action_mode_statistic_ = nullptr;
+    KToggleAction *action_mode_numeral_ = nullptr;
 
-    QList<QAbstractButton*> function_button_list_;
-    QList<QAbstractButton*> stat_button_list_;
-    QList<QAbstractButton*> mem_button_list_;
-    QList<QAbstractButton*> operation_button_list_;
+    QList<QAbstractButton *> function_button_list_;
+    QList<QAbstractButton *> stat_button_list_;
+    QList<QAbstractButton *> mem_button_list_;
+    QList<QAbstractButton *> operation_button_list_;
 
     CalcEngine core;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KCalculator::UpdateFlags)
 
-#endif
